@@ -3,7 +3,7 @@ package Pod::Weaver::PluginBundle::DROLSKY;
 use strict;
 use warnings;
 
-our $VERSION = '0.79';
+our $VERSION = '0.80';
 
 use namespace::autoclean -also => ['_exp'];
 
@@ -80,7 +80,11 @@ sub configure {
                 match_anywhere => 0,
             },
         ],
-        [ $self->_source_section ],
+
+        # We don't enable GitHub::Meta under Travis so we don't have
+        # repository metadata. That means we end up generating an empty L<>
+        # tag and our pod syntax test fails.
+        ( $ENV{TRAVIS} ? () : [ $self->_source_section ] ),
     );
 
     my $config
@@ -298,7 +302,7 @@ Pod::Weaver::PluginBundle::DROLSKY - A plugin bundle for pod woven by DROLSKY
 
 =head1 VERSION
 
-version 0.79
+version 0.80
 
 =head1 SYNOPSIS
 
